"""
Adapters based on top of FastAPI.

At the momdent, the code is highly coupled with FastAPI,
some part of the code import fastapi directly for legacy reason,
but it shouldn't.

All FastAPI dependency should be contained in this module.
"""
