{# doc
  Produce ``<input>`` node.
#}
{# def
  name: Annotated[str, "submitted name in the form"],
  value: Annotated[str, "submitted value in the form"] = "",
  type: Annotated[str, "type of the control"] = "text",
  id: Annotated[str | None, "unique identifier of the element."] = None,
  class_: Annotated[
    str | None,
    "css class for the node, defaults to "
    ":attr:`fastlife.template_globals.Globals.INPUT_CLASS`."
  ] = None,
  aria_label: Annotated[str | None, "aria-label"] = None,
  placeholder: Annotated[
    str | None,
    "brief hint to the user as to what kind of information is expected in the field."
  ] = None,
  inputmode: Annotated[
      Literal[
        "none", "text", "decimal", "numeric", "tel", "search", "email", "url"
      ] | None,
      "Define a virtual keyboard layout"
  ] = None,
  autocomplete: Annotated[
    Literal[
      "on", "off",
      "name", "username", "current-password", "new-password", "one-time-code",
      "email", "tel", "organization", "street-address",
      "address-line1", "address-line2", "address-line3",
      "postal-code", "country", "country-name",
      "cc-name", "cc-number", "cc-exp", "cc-csc",
      "tel-country-code", "tel-national", "tel-area-code",
      "tel-local", "tel-extension",
      "bday", "bday-day", "bday-month", "bday-year",
      "transaction-amount", "transaction-currency"
    ] | None,
    "Define autocomplete mode"
  ] = None,
  autofocus: Annotated[bool, "Five the focus"] = False,
#}

<input name="{{name}}" value="{{value|default('')}}" type="{{type}}"
  {%- if id %} id="{{id}}" {%- endif %}
  {%- if aria_label %} aria-label="{{ gettext(aria_label) }}" {%- endif %}
  {%- if placeholder %} placeholder="{{ gettext(placeholder) }}" {%- endif %}
  {%- if inputmode %} inputmode="{{inputmode}}" {%- endif %}
  {%- if autocomplete %} autocomplete="{{autocomplete}}" {%- endif %}
  class="{{attrs.class or INPUT_CLASS}}"
  {%- if autofocus %} autofocus{% endif -%}
/>
