{# doc
  Create html ``<a>`` node with htmx support by default.
  The `hx-get` parameter is set with the href directly unless the
  `disabled-htmx` attribute has been set.
#}
{# def
  href: Annotated[str, "target link."],
  id: Annotated[str | None, "unique identifier of the element."] = None,
  class_: Annotated[
    str | None,
    "css class for the node, defaults to :attr:`fastlife.template_globals.Globals.A_CLASS`."
  ] = None,
  hx_target: Annotated[
    str,
    "target the element for swapping than the one issuing the AJAX request."
  ] = "#maincontent",
  hx_select: Annotated[str | None, "select the content swapped from response of the AJAX request."] = None,
  hx_swap: Annotated[
    str,
    "specify how the response will be swapped in relative to the target of an AJAX request."
  ] = "innerHTML show:body:top",
  hx_push_url: Annotated[bool, "replace the browser url with the link."] = True,
  hx_get: Annotated[
    str | None,
    "Override the target link only for htmx request for component rendering. href will be used if None."
  ] = None,
  disable_htmx: Annotated[bool, "do not add any `hx-*` attibute to the link."] = False
#}

<a href="{{href}}"
  {%- if id %} id="{{ id }}" {%- endif %}
  {%- if not disable_htmx %}
    hx-get="{{ hx_get or href }}"
    hx-target="{{ hx_target }}"
    hx-swap="{{ hx_swap }}"
    {%- if hx_push_url %} hx-push-url="true" {%- endif %}
    {%- if hx_select %} hx-select="{{ hx_select }}" {%- endif %}
  {%- endif %}
    class="{{ attrs.class or A_CLASS }}"
>
  {{- content -}}
</a>
