{# def
    id: Annotated[str | "unique identifier of the element."] = None,
    title: Annotated[str | None, "title element of the svg"] = None,
    class_: Annotated[str | None, "css classapplide to the svg element"] = None,
#}
<svg xmlns="http://www.w3.org/2000/svg" fill="none" {% if id %}id="{{id}}" {%endif%}class="{{attrs.class or ''}}" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" aria-hidden="true">
  <path stroke-linecap="round" stroke-linejoin="round" d="M15.362 5.214A8.252 8.252 0 0 1 12 21 8.25 8.25 0 0 1 6.038 7.047 8.287 8.287 0 0 0 9 9.601a8.983 8.983 0 0 1 3.361-6.867 8.21 8.21 0 0 0 3 2.48Z">{% if title %}<title>{{title}}</title>{% endif %}</path>
  <path stroke-linecap="round" stroke-linejoin="round" d="M12 18a3.75 3.75 0 0 0 .495-7.468 5.99 5.99 0 0 0-1.925 3.547 5.975 5.975 0 0 1-2.133-1.001A3.75 3.75 0 0 0 12 18Z">{% if title %}<title>{{title}}</title>{% endif %}</path>
</svg>
