{# doc
  Produce ``<input type="password">`` node.
#}
{# def
  name: Annotated[str, "submitted name in the form"],
  id: Annotated[str | None, "unique identifier of the element."] = None,
  class_: Annotated[
    str | None,
    "css class for the node, defaults to "
    ":attr:`fastlife.template_globals.Globals.INPUT_CLASS`."
  ] = None,
  aria_label: Annotated[str | None, "aria-label"] = None,
  placeholder: Annotated[
    str | None,
    "brief hint to the user as to what kind of information is expected in the field."
  ] = None,
  autocomplete: Annotated[
    Literal[
      "on", "off",
      "current-password", "new-password",
    ] | None,
    "Define autocomplete mode"
  ] = None,
  inputmode: Annotated[
      Literal[
        "none", "text", "numeric",
      ] | None,
      "Define a virtual keyboard layout"
  ] = None,
  minlength: Annotated[int | None, "Minimum length"] = None,
  maxlength: Annotated[int | None, "Maximum length"] = None,
  pattern: Annotated[str | None, "Must match a pattern"] = None,
  autofocus: Annotated[bool, "Five the focus"] = False,
  required: Annotated[bool, "Mark as required field"] = False,
  readonly: Annotated[bool, "Mark as readonly field"] = False,
#}

<input name="{{name}}" type="password"
  {%- if id %} id="{{id}}" {%- endif %}
  {%- if aria_label %} aria-label="{{aria_label}}" {%- endif %}
  {%- if placeholder %} placeholder="{{placeholder}}" {%- endif %}
  {%- if autocomplete %} autocomplete="{{autocomplete}}" {%- endif %}
  {%- if inputmode %} inputmode="{{inputmode}}" {%- endif %}
  {%- if minlength %} minlength="{{minlength}}" {%- endif %}
  {%- if maxlength %} maxlength="{{maxlength}}" {%- endif %}
  {%- if pattern %} pattern="{{pattern}}" {%- endif %}
  class="{{attrs.class or INPUT_CLASS}}"
  {%- if autofocus %} autofocus{% endif -%}
  {%- if required %} required{% endif -%}
  {%- if readonly %} readonly{% endif -%}
/>
