{# doc display an error for a field. #}
{# def
  message: Annotated[str | None, "error message"],
  class_: Annotated[
    str | None,
    "css class for the node, defaults to :attr:`fastlife.template_globals.Globals.FATAL_ERROR_CLASS`."
  ] = None,
  icon_class: Annotated[
    str | None,
    "css class for the node, defaults to :attr:`fastlife.template_globals.Globals.FATAL_ERROR_ICON_CLASS`."
  ] = None,
  text_class: Annotated[
    str | None,
    "css class for the node, defaults to :attr:`fastlife.template_globals.Globals.FATAL_ERROR_TEXT_CLASS`."
  ] = None,
 #}
{%- if message -%}
<div class="{{attrs.class or FATAL_ERROR_CLASS}}" role="alert">
  <icons.Fire :class="icon_class or FATAL_ERROR_ICON_CLASS" />
  <span class="{{text_class or FATAL_ERROR_TEXT_CLASS}}">{{ message }}</span>
</div>
{%- endif -%}