{# doc
  Create html ``<select>`` node.
#}
{# def
name: Annotated[str, "name of the submitted"],
id: Annotated[str | None, "unique identifier of the element."] = None,
class_: Annotated[
  str | None,
  "css class for the node, defaults to "
  ":attr:`fastlife.template_globals.Globals.SELECT_CLASS`."
] = None,
multiple: Annotated[bool, "Mark as multiple"] = False,
#}

<select name="{{name}}"
  {%- if id %} id="{{ id }}" {%- endif %}
  class="{{attrs.class or SELECT_CLASS}}"
  {%- if multiple %} multiple {%- endif %}>
  {{- content -}}
</select>
