{# doc display an error for a field. #}
{# def
  text: Annotated[str | None, "error message"],
  class_: Annotated[
    str | None,
    "css class for the node, defaults to :attr:`fastlife.template_globals.Globals.ERROR_CLASS`."
  ] = None,
#}
{%- if text -%}
<span class="{{attrs.class or ERROR_CLASS }}">{{ text }}</span>
{%- endif -%}