{# Display a hint message for a field. #}
{# def text: Annotated[str | None, "hint text."] #}
{% if text %}
<span class="mt-2 text-sm text-neutral-500 dark:text-neutral-400">{{text}}</span>
{% endif %}
