{# def
    id: Annotated[str | "unique identifier of the element."] = None,
    title: Annotated[str | None, "title element of the svg"] = None,
    class_: Annotated[str | None, "css classapplide to the svg element"] = None,
#}
<svg xmlns="http://www.w3.org/2000/svg" {% if id %}id="{{id}}" {%endif%}class="{{attrs.class or ''}}" viewBox="0 0 16 16" fill="currentColor" aria-hidden="true">
  <path d="M8.543 2.232a.75.75 0 0 0-1.085 0l-5.25 5.5A.75.75 0 0 0 2.75 9H4v4a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1v-1a1 1 0 1 1 2 0v1a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V9h1.25a.75.75 0 0 0 .543-1.268l-5.25-5.5Z">{% if title %}<title>{{title}}</title>{% endif %}</path>
</svg>
