{# doc html ``<table>`` node. #}
{# def
  id: Annotated[str | None, "unique identifier of the element."] = None,
  class_: Annotated[
    str | None,
    "css class for the node, defaults to "
    ":attr:`fastlife.template_globals.Globals.TABLE_CLASS`."
  ] = None,
#}
<table
  {%- if id %} id="{{id}}" {%- endif %}
  class="{{attrs.class or TABLE_CLASS}}">
  {{- content -}}
</table>
